@@ -282,6 +282,6 @@ Marc Lehmann <pcg@goof.com>
 
 =head1 SEE ALSO
 
-perl(1), L<Gimp>,
+perl(1), L<Gimp>.
 
 =cut
